@@ -18,7 +18,7 @@
 */
 
 
-// $RCSfile: dwtext.cpp,v $ $Revision: 1.2.2.1 $
+// $RCSfile: dwtext.cpp,v $ $Revision: 1.2.2.2 $
 
 
 // Microsoft Windows 3.n text window for Ghostscript.
@@ -886,19 +886,19 @@ TextWindow::WndProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 	case WM_CREATE:
 	    {
 	    RECT crect, wrect;
+	    int cx, cy;
 
 	    TextWindow::hwnd = hwnd;
 
+	    /* make window no larger than screen buffer */
 	    GetClientRect(hwnd, &crect);
-	    if ( (CharSize.y*ScreenSize.y < crect.bottom)
-	      || (CharSize.x*ScreenSize.x < crect.right) ) {
-		    /* shrink size */
-		GetWindowRect(hwnd,&wrect);
-		MoveWindow(hwnd, wrect.left, wrect.top,
-		     wrect.right-wrect.left + (CharSize.x*ScreenSize.x - crect.right),
-		     wrect.bottom-wrect.top + (CharSize.y*ScreenSize.y - crect.bottom),
+	    GetWindowRect(hwnd,&wrect);
+	    cx = min(CharSize.x*ScreenSize.x, crect.right);
+	    cy = min(CharSize.y*ScreenSize.y, crect.bottom);
+	    MoveWindow(hwnd, wrect.left, wrect.top,
+		wrect.right-wrect.left + (cx - crect.right),
+		wrect.bottom-wrect.top + (cy - crect.bottom),
 		     TRUE);
-	    }
 	    if ( (DragPre!=(LPSTR)NULL) && (DragPost!=(LPSTR)NULL) )
 		DragAcceptFiles(hwnd, TRUE);
 	    }
