@@ -17,7 +17,7 @@
   copies.
 */
 
-/*$RCSfile: gdevpdf.c,v $ $Revision: 1.21.2.4 $ */
+/*$RCSfile: gdevpdf.c,v $ $Revision: 1.21.2.5 $ */
 /* PDF-writing driver */
 #include "memory_.h"
 #include "string_.h"
@@ -602,7 +602,7 @@ pdf_close_page(gx_device_pdf * pdev)
 			if (!any) {
 			    page->resource_ids[i] = pdf_begin_obj(pdev);
 			    s = pdev->strm;
-			    pputs(s, "<<");
+			    stream_puts(s, "<<");
 			    any = true;
 			}
 			pprintld2(s, "/R%ld\n%ld 0 R", id, id);
@@ -610,7 +610,7 @@ pdf_close_page(gx_device_pdf * pdev)
 		}
 	    }
 	    if (any) {
-		pputs(s, ">>\n");
+		stream_puts(s, ">>\n");
 		pdf_end_obj(pdev);
 		pdf_write_resource_objects(pdev, i);
 	    }
@@ -638,7 +638,7 @@ pdf_close_page(gx_device_pdf * pdev)
 		    if (!any) {
 			page->fonts_id = pdf_begin_obj(pdev);
 			s = pdev->strm;
-			pputs(s, "<<");
+			stream_puts(s, "<<");
 			any = true;
 		    }
 		    pprints1(s, "/%s", font->frname);
@@ -653,7 +653,7 @@ pdf_close_page(gx_device_pdf * pdev)
 	    }
 	}
 	if (any) {
-	    pputs(s, ">>\n");
+	    stream_puts(s, ">>\n");
 	    pdf_end_obj(pdev);
 	}
     }
@@ -700,16 +700,16 @@ pdf_write_page(gx_device_pdf *pdev, int page_num)
     if (page->text_rotation.Rotate >= 0)
 	pprintd1(s, "/Rotate %d", page->text_rotation.Rotate);
     pprintld1(s, "/Parent %ld 0 R\n", pdev->Pages->id);
-    pputs(s, "/Resources<</ProcSet[/PDF");
+    stream_puts(s, "/Resources<</ProcSet[/PDF");
     if (page->procsets & ImageB)
-	pputs(s, " /ImageB");
+	stream_puts(s, " /ImageB");
     if (page->procsets & ImageC)
-	pputs(s, " /ImageC");
+	stream_puts(s, " /ImageC");
     if (page->procsets & ImageI)
-	pputs(s, " /ImageI");
+	stream_puts(s, " /ImageI");
     if (page->procsets & Text)
-	pputs(s, " /Text");
-    pputs(s, "]\n");
+	stream_puts(s, " /Text");
+    stream_puts(s, "]\n");
     {
 	int i;
 
@@ -721,18 +721,18 @@ pdf_write_page(gx_device_pdf *pdev, int page_num)
     }
     if (page->fonts_id)
 	pprintld1(s, "/Font %ld 0 R\n", page->fonts_id);
-    pputs(s, ">>\n");
+    stream_puts(s, ">>\n");
 
     /* Write out the annotations array if any. */
 
     if (page->Annots) {
-	pputs(s, "/Annots");
+	stream_puts(s, "/Annots");
 	COS_WRITE(page->Annots, pdev);
 	COS_FREE(page->Annots, "pdf_write_page(Annots)");
 	page->Annots = 0;
     }
     if (page->contents_id == 0)
-	pputs(s, "/Contents []\n");
+	stream_puts(s, "/Contents []\n");
     else
 	pprintld1(s, "/Contents %ld 0 R\n", page->contents_id);
 
@@ -740,7 +740,7 @@ pdf_write_page(gx_device_pdf *pdev, int page_num)
 
     cos_dict_elements_write(page->Page, pdev);
 
-    pputs(s, ">>\n");
+    stream_puts(s, ">>\n");
     pdf_end_obj(pdev);
     return 0;
 }
@@ -801,7 +801,7 @@ pdf_close(gx_device * dev)
 
     pdf_open_obj(pdev, Pages_id);
     s = pdev->strm;
-    pputs(s, "<< /Type /Pages /Kids [\n");
+    stream_puts(s, "<< /Type /Pages /Kids [\n");
     /* Omit the last page if it was incomplete. */
     if (partial_page)
 	--(pdev->next_page);
@@ -816,7 +816,7 @@ pdf_close(gx_device * dev)
 	pprintd1(s, "/Rotate %d\n",
 		 pdf_dominant_rotation(&pdev->text_rotation));
     cos_dict_elements_write(pdev->Pages, pdev);
-    pputs(s, ">>\n");
+    stream_puts(s, ">>\n");
     pdf_end_obj(pdev);
 
     /* Close outlines and articles. */
@@ -857,19 +857,19 @@ pdf_close(gx_device * dev)
 
 	Threads_id = pdf_begin_obj(pdev);
 	s = pdev->strm;
-	pputs(s, "[ ");
+	stream_puts(s, "[ ");
 	while ((part = pdev->articles) != 0) {
 	    pdev->articles = part->next;
 	    pprintld1(s, "%ld 0 R\n", part->contents->id);
 	    COS_FREE(part->contents, "pdf_close(article contents)");
 	    gs_free_object(mem, part, "pdf_close(article)");
 	}
-	pputs(s, "]\n");
+	stream_puts(s, "]\n");
 	pdf_end_obj(pdev);
     }
     pdf_open_obj(pdev, Catalog_id);
     s = pdev->strm;
-    pputs(s, "<<");
+    stream_puts(s, "<<");
     pprintld1(s, "/Type /Catalog /Pages %ld 0 R\n", Pages_id);
     if (pdev->outlines_id != 0)
 	pprintld1(s, "/Outlines %ld 0 R\n", pdev->outlines_id);
@@ -878,7 +878,7 @@ pdf_close(gx_device * dev)
     if (pdev->Dests)
 	pprintld1(s, "/Dests %ld 0 R\n", pdev->Dests->id);
     cos_dict_elements_write(pdev->Catalog, pdev);
-    pputs(s, ">>\n");
+    stream_puts(s, ">>\n");
     pdf_end_obj(pdev);
     if (pdev->Dests) {
 	COS_FREE(pdev->Dests, "pdf_close(Dests)");
@@ -941,16 +941,16 @@ pdf_close(gx_device * dev)
 	    if (pos & ASIDES_BASE_POSITION)
 		pos += resource_pos - ASIDES_BASE_POSITION;
 	    sprintf(str, "%010ld 00000 n \n", pos);
-	    pputs(s, str);
+	    stream_puts(s, str);
 	}
     }
 
     /* Write the trailer. */
 
-    pputs(s, "trailer\n");
+    stream_puts(s, "trailer\n");
     pprintld3(s, "<< /Size %ld /Root %ld 0 R /Info %ld 0 R\n",
 	      pdev->next_id, Catalog_id, Info_id);
-    pputs(s, ">>\n");
+    stream_puts(s, ">>\n");
     pprintld1(s, "startxref\n%ld\n%%%%EOF\n", xref);
 
     /* Release the resource records. */
