@@ -17,7 +17,7 @@
   copies.
 */
 
-/*$RCSfile: gdevprn.c,v $ $Revision: 1.5.2.1 $ */
+/*$RCSfile: gdevprn.c,v $ $Revision: 1.5.2.3 $ */
 /* Generic printer driver support */
 #include "ctype_.h"
 #include "gdevprn.h"
@@ -591,6 +591,12 @@ label:\
 
     switch (code = param_read_string(plist, (param_name = "OutputFile"), &ofs)) {
 	case 0:
+	    if (pdev->LockSafetyParams &&
+		    bytes_compare(ofs.data, ofs.size,
+			(const byte *)ppdev->fname, strlen(ppdev->fname))) {
+	        code = gs_error_invalidaccess;
+	    }
+	    else
 	    code = validate_output_file(&ofs);
 	    if (code >= 0)
 		break;
