@@ -1,4 +1,4 @@
-/* Copyright (C) 1993, 2000 Aladdin Enterprises.  All rights reserved.
+/* Copyright (C) 1993, 2002 artofcode LLC.  All rights reserved.
   
   This file is part of GNU Ghostscript.
   
@@ -17,7 +17,7 @@
   copies.
 */
 
-/*$RCSfile: gsparam.h,v $ $Revision: 1.7.2.1 $ */
+/* $Id: gsparam.h,v 1.7.2.2 2002/01/23 04:15:50 giles Exp $ */
 /* Client interface to parameter dictionaries */
 
 #ifndef gsparam_INCLUDED
@@ -85,6 +85,11 @@ typedef _param_array_struct(gs_param_string_array_s, gs_param_string) gs_param_s
   ((ps).data = (const byte *)(str),\
    (ps).size = strlen((const char *)(ps).data),\
    (ps).persistent = true)
+   
+#define param_string_from_transient_string(ps, str)\
+  ((ps).data = (const byte *)(str),\
+   (ps).size = strlen((const char *)(ps).data),\
+   (ps).persistent = false)
 
 /*
  * Define the structure for heterogenous collection values (dictionaries
