@@ -17,7 +17,7 @@
   copies.
 */
 
-/*$RCSfile: gstext.c,v $ $Revision: 1.3.2.2 $ */
+/*$RCSfile: gstext.c,v $ $Revision: 1.3.2.3 $ */
 /* Driver text interface support */
 #include "memory_.h"
 #include "gstypes.h"
@@ -301,16 +301,36 @@ gs_xyshow_begin(gs_state * pgs, const byte * str, uint size,
     text.widths_size = widths_size;
     return gs_text_begin(pgs, &text, mem, ppte);
 }
+
+private void
+setup_FontBBox_as_Metrics2 (gs_text_enum_t * pte, gs_font * pfont)
+{
+    /* When we exec a operator like `show' that has a a chance to get
+       a glyph from a char, we can set FontBBox_as_Metrics2 in
+       gschar0.c:gs_type0_next_char_glyph.  In other hand, when we
+       exec a operator like `glyphshow' that get a glyph directly from
+       an input file, gschar0.c:gs_type0_next_char_glyph is exec'ed.
+       For the later case, we set up FontBBox_as_Metrics2 with using
+       this procedure.. */
+    if (pfont->FontType == ft_CID_encrypted
+	|| pfont->FontType == ft_CID_TrueType)
+        pte->FontBBox_as_Metrics2 = ((gs_font_base *)pfont)->FontBBox.q;
+}
+
 int
 gs_glyphshow_begin(gs_state * pgs, gs_glyph glyph,
 		   gs_memory_t * mem, gs_text_enum_t ** ppte)
 {
     gs_text_params_t text;
+    int result;
 
     text.operation = TEXT_FROM_SINGLE_GLYPH | TEXT_DO_DRAW | TEXT_RETURN_WIDTH;
     text.data.d_glyph = glyph;
     text.size = 1;
-    return gs_text_begin(pgs, &text, mem, ppte);
+    result = gs_text_begin(pgs, &text, mem, ppte);
+    if (result == 0)
+      setup_FontBBox_as_Metrics2(*ppte, pgs->font);
+    return result;
 }
 int
 gs_cshow_begin(gs_state * pgs, const byte * str, uint size,
@@ -359,23 +379,31 @@ gs_glyphpath_begin(gs_state * pgs, gs_glyph glyph, bool stroke_path,
 		   gs_memory_t * mem, gs_text_enum_t ** ppte)
 {
     gs_text_params_t text;
+    int result;
 
     text.operation = TEXT_FROM_SINGLE_GLYPH | TEXT_RETURN_WIDTH |
 	(stroke_path ? TEXT_DO_TRUE_CHARPATH : TEXT_DO_FALSE_CHARPATH);
     text.data.d_glyph = glyph;
     text.size = 1;
-    return gs_text_begin(pgs, &text, mem, ppte);
+    result = gs_text_begin(pgs, &text, mem, ppte);
+    if (result == 0)
+      setup_FontBBox_as_Metrics2(*ppte, pgs->font);
+    return result;
 }
 int
 gs_glyphwidth_begin(gs_state * pgs, gs_glyph glyph,
 		    gs_memory_t * mem, gs_text_enum_t ** ppte)
 {
     gs_text_params_t text;
+    int result;
 
     text.operation = TEXT_FROM_SINGLE_GLYPH | TEXT_DO_NONE | TEXT_RETURN_WIDTH;
     text.data.d_glyph = glyph;
     text.size = 1;
-    return gs_text_begin(pgs, &text, mem, ppte);
+    result = gs_text_begin(pgs, &text, mem, ppte);
+    if (result == 0)
+      setup_FontBBox_as_Metrics2(*ppte, pgs->font);
+    return result;
 }
 
 /* Restart processing with different parameters. */
@@ -387,6 +415,7 @@ gs_text_restart(gs_text_enum_t *pte, const gs_text_params_t *text)
     tenum = *pte;
     tenum.text = *text;
     gs_text_enum_init_dynamic(&tenum, pte->orig_font);
+    setup_FontBBox_as_Metrics2(pte, pte->orig_font);
     return gs_text_resync(pte, &tenum);
 }
 
